@@ -7,7 +7,6 @@
 import time
 import sys
 import os
-
 from fast_tracker import config
 
 
@@ -34,8 +33,18 @@ def log(text, *args, level=1):
     :param int level: 日志级别, 数字越高，打印信息越多，为0表示不打印日志。暂定级别有：0，1，2，3，4 可对应为logging的日志级别
     :return:
     """
-    if config.tracker_logging.get("Level") :
+    if config.tracker_logging.get("Level"):
         text = text % args
         timestamp = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
-        sys.stdout.write("FAST: %s (%d) - %s\n" % (timestamp, os.getpid(), text))
+        sys.stdout.write("FAST: %s (%d) - %s\n" % (timestamp, os.getpid(),text))
         sys.stdout.flush()
+
+def getUri(text):
+    if "http://" in text:
+        index = text.find("//")
+        domain = text[index + 2:]
+        index = domain.find("/")
+        return domain[index:]
+    else:
+        index = text.find("/")
+    return text[index:]
